#!/bin/sh

DIR="`pwd`/`dirname $0`/testgridConfiguration";

check_probe() {
  name=$1
  command=$2
  expected_output=$3
  printf '%-25s' $name  
  if [ $name = "check_cis" -o $name = "check_uvos" ]; then
    echo "NA"  
  else
    `/usr/libexec/grid-monitoring/probes/pl.plgrid/UNICORE/umi2/$name/$name.pl -f $DIR/$name.config $command > /tmp/unicore-testgrid/logs/output 2> /dev/null`
    `head -1 /tmp/unicore-testgrid/logs/output | grep -cq "$expected_output"`
    if [ $? -eq 0 ]; then
      echo -n "PASS ("
      echo -n `head -1 /tmp/unicore-testgrid/logs/output`
      echo ")"
    else
      echo "FAIL"
      cat /tmp/unicore-testgrid/logs/output
#      rm -f /tmp/unicore-testgrid/logs/cache.txt $DIR/check_gateway.config $DIR/check_workflow_test.swf $DIR/check_registry.config $DIR/check_workflow.config
#      exit 1
    fi
  fi
}

sed -e"s|<DIR>|$DIR|" $DIR/check_workflow.config.dist > $DIR/check_workflow.config
sed -e"s|<SECOND_TSF>|https://omiiei.zam.kfa-juelich.de:6000/Bravo-Site/services/TargetSystemFactoryService?res=default_target_system_factory|" $DIR/check_workflow_test.swf.dist > $DIR/check_workflow_test.swf
check_probe 'check_workflow' '' 'OK: Workflow submission succeded'

DFILE=$DIR/"/date.u";
check_probe 'check_application' "$DFILE 'not_empty(#stdout)'" 'OK: .* job succeded'
check_probe 'check_application' "$DFILE \"grep(NOT_THE_DATE,#stdout)\"" 'WARNING: Unable to pass application condition string.'
check_probe 'check_application' "$DFILE \"(not_empty(#stdout\"" 'UNKNOWN: Wrong condition syntax! See README file.'

check_probe 'check_cip' '' 'WARNING: CIP works, but does not process information.'

check_probe 'check_freespace' '' 'OK: There is .* of free space on'
check_probe 'check_freespace' '-w 10000000000000' 'WARNING: There is .* of free space on'

sed -e"s|<SERVICES>|Alpha-Site, Bravo-Site, Workflow, ServOrch|" $DIR/check_gateway.config.dist > $DIR/check_gateway.config
check_probe 'check_gateway' '' 'OK: Gateway works properly, .* services found'
sed -e"s|<SERVICES>|ONE_ANOTHER_SITE|" $DIR/check_gateway.config.dist > $DIR/check_gateway.config
check_probe 'check_gateway' '' 'WARNING: Required services not found: ONE_ANOTHER_SITE'

sed -e"s|<SERVICES>|https://omiiei.zam.kfa-juelich.de:6000/Bravo-Site/services/StorageFactory?res=default_storage_factory|" $DIR/check_registry.config.dist > $DIR/check_registry.config
check_probe 'check_registry' '' 'OK: Registry works, .* services found'
sed -e"s|<SERVICES>|https://omiiei.zam.kfa-juelich.de:6000/Bravo-Site/services/StorageFactories|" $DIR/check_registry.config.dist > $DIR/check_registry.config
check_probe 'check_registry' '' 'CRITICAL: Some required services not found:'

check_probe 'check_servorch' '' 'OK: Service Orchestator appears to work, sites registered in GRIS:'

check_probe 'check_storagefactory' '' 'OK: Storage factory at .* works'

check_probe 'check_sms' '' 'OK: SMS at .* works with '

check_probe 'check_unicorex' '' 'OK: Found .* TSS instance'

check_probe 'check_versions' '' 'Up-to-date: .*, outdated: .*, unknown: .*'

check_probe 'check_workflowservice' '' 'OK: Workflow Service works normally, found workflows:'

check_probe 'check_workflow' '' 'OK: Wokflow succeeded! Time elapsed: '
sed -e"s|<SECOND_TSF>|https://omiiei.zam.kfa-juelich.de:6000/CBravo-Site/services/TargetSystemFactoryService?res=default_target_system_factory|" $DIR/check_workflow_test.swf.dist > $DIR/check_workflow_test.swf
check_probe 'check_workflow' '' 'CRITICAL: Some TSFs are not available in the Registry: '


rm -f /tmp/unicore-testgrid/logs/cache.txt $DIR/check_gateway.config $DIR/check_workflow_test.swf $DIR/check_registry.config $DIR/check_workflow.config

#check_probe 'check_cis'   # N   O   T
#check_probe 'check_uvos'  # AVAILABLE
